## Calendar

### views

##### default

    <div date-picker="start"></div>

##### year

    <div date-picker="start"  year></div>

##### month

    <div date-picker="start month></div>

##### date

    <div date-picker="start" date></div>

##### hours

    <div date-picker="start" hours></div>

##### minutes

    <div date-picker="start" minutes></div>

### Input

##### default

### Input with append

##### default

    <input type="datetime" ng-model="model" date-time></div>

### Input with prepend

##### default

    <input type="datetime" ng-model="model" date-time></div>

##### Input format

    <input type="datetime" ng-model="model" date-time format="long"></div>

##### A button

    <div class="dropdown">
      <a class="dropdown-toggle btn btn-danger">
        pick a date: {{(date|date)}}
      </a>
      <div class="dropdown-menu" ng-click="$event.preventDefault();$event.stopPropagation()">
        <div date-picker="date" class="datetimepicker"></div>
      </div>
    </div>

pick a date: {{(date|date)}}

##### Date range

    <div date-range start="start" end="end" ></div>

##### Date range button

{{(a|date)||"pick start"}} - {{(b|date)||"pick end"}}